Learn R Programming

gsearly (version 1.0.0)

tfuStandard: Standardize follow-up times

Description

Standardize the follow-up (early) time-points.

Usage

tfuStandard(tfu, tref=c(1,2))

Value

A list containing the following components.

tfu

Follow-up time points.

stfu

Standardized follow-up time-points, depending on the selected reference categories tref.

Arguments

tfu

A vector of length s, of follow-up time points, in the same units as the recruitment time (trecruit) from from function gsearlyModel or gsearlyUser.

tref

A vector of integers of length 2 that defines the correlation parameter rho for the exponential model corrExp; the parameter rho is the correlation between data at times tfu[tref[1]] and tfu[tref[2]], with default c(1,2).

Examples

Run this code

 # Early outcomes at 3, 6 and 12 months, and final at 24 months
 # Standardized to units of 3 months if tref is c(1,2)
 tfuStandard(c(3,6,12,24), tref=c(1,2))

 # Standardized to yearly units if tref is c(1,2)
 tfuStandard(c(3,6,12,24), tref=c(3,4))

Run the code above in your browser using DataLab